==> plantuml-libs-6.0.0.tgz: package/distribution/aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsDirectoryServiceAdConnector.md <==
# AwsDirectoryServiceAdConnector


```text
aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsDirectoryServiceAdConnector
```

```text
include('aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsDirectoryServiceAdConnector')
```



| Illustration | AwsDirectoryServiceAdConnector | AwsDirectoryServiceAdConnectorCard | AwsDirectoryServiceAdConnectorGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsDirectoryServiceAdConnector.png) | ![illustration for AwsDirectoryServiceAdConnector](../../../aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsDirectoryServiceAdConnector.Local.png) | ![illustration for AwsDirectoryServiceAdConnectorCard](../../../aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsDirectoryServiceAdConnectorCard.Local.png) | ![illustration for AwsDirectoryServiceAdConnectorGroup](../../../aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsDirectoryServiceAdConnectorGroup.Local.png) |




## AwsDirectoryServiceAdConnector

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsDirectoryServiceAdConnector
include('aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsDirectoryServiceAdConnector')

' renders the element
AwsDirectoryServiceAdConnector('AwsDirectoryServiceAdConnector', 'Aws Directory Service Ad Connector', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsDirectoryServiceAdConnector
include('aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsDirectoryServiceAdConnector')

' renders the element
AwsDirectoryServiceAdConnector('AwsDirectoryServiceAdConnector', 'Aws Directory Service Ad Connector', 'an optional tech label')
@enduml
```

## AwsDirectoryServiceAdConnectorCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsDirectoryServiceAdConnectorCard
include('aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsDirectoryServiceAdConnector')

' renders the element
AwsDirectoryServiceAdConnectorCard('AwsDirectoryServiceAdConnectorCard', 'Aws Directory Service Ad Connector Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsDirectoryServiceAdConnectorCard
include('aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsDirectoryServiceAdConnector')

' renders the element
AwsDirectoryServiceAdConnectorCard('AwsDirectoryServiceAdConnectorCard', 'Aws Directory Service Ad Connector Card', 'an optional description')
@enduml
```

## AwsDirectoryServiceAdConnectorGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsDirectoryServiceAdConnectorGroup
include('aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsDirectoryServiceAdConnector')

' renders the element
AwsDirectoryServiceAdConnectorGroup('AwsDirectoryServiceAdConnectorGroup', 'Aws Directory Service Ad Connector Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsDirectoryServiceAdConnectorGroup
include('aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsDirectoryServiceAdConnector')

' renders the element
AwsDirectoryServiceAdConnectorGroup('AwsDirectoryServiceAdConnectorGroup', 'Aws Directory Service Ad Connector Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.4.0.tgz: package/distribution/aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsDirectoryServiceAdConnector.md <==
# AwsDirectoryServiceAdConnector


```text
aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsDirectoryServiceAdConnector
```

```text
include('aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsDirectoryServiceAdConnector')
```



| Illustration | AwsDirectoryServiceAdConnector | AwsDirectoryServiceAdConnectorCard | AwsDirectoryServiceAdConnectorGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsDirectoryServiceAdConnector.png) | ![illustration for AwsDirectoryServiceAdConnector](../../../aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsDirectoryServiceAdConnector.Local.png) | ![illustration for AwsDirectoryServiceAdConnectorCard](../../../aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsDirectoryServiceAdConnectorCard.Local.png) | ![illustration for AwsDirectoryServiceAdConnectorGroup](../../../aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsDirectoryServiceAdConnectorGroup.Local.png) |




## AwsDirectoryServiceAdConnector

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsDirectoryServiceAdConnector
include('aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsDirectoryServiceAdConnector')

' renders the element
AwsDirectoryServiceAdConnector('AwsDirectoryServiceAdConnector', 'Aws Directory Service Ad Connector', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsDirectoryServiceAdConnector
include('aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsDirectoryServiceAdConnector')

' renders the element
AwsDirectoryServiceAdConnector('AwsDirectoryServiceAdConnector', 'Aws Directory Service Ad Connector', 'an optional tech label')
@enduml
```

## AwsDirectoryServiceAdConnectorCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsDirectoryServiceAdConnectorCard
include('aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsDirectoryServiceAdConnector')

' renders the element
AwsDirectoryServiceAdConnectorCard('AwsDirectoryServiceAdConnectorCard', 'Aws Directory Service Ad Connector Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsDirectoryServiceAdConnectorCard
include('aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsDirectoryServiceAdConnector')

' renders the element
AwsDirectoryServiceAdConnectorCard('AwsDirectoryServiceAdConnectorCard', 'Aws Directory Service Ad Connector Card', 'an optional description')
@enduml
```

## AwsDirectoryServiceAdConnectorGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsDirectoryServiceAdConnectorGroup
include('aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsDirectoryServiceAdConnector')

' renders the element
AwsDirectoryServiceAdConnectorGroup('AwsDirectoryServiceAdConnectorGroup', 'Aws Directory Service Ad Connector Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsDirectoryServiceAdConnectorGroup
include('aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsDirectoryServiceAdConnector')

' renders the element
AwsDirectoryServiceAdConnectorGroup('AwsDirectoryServiceAdConnectorGroup', 'Aws Directory Service Ad Connector Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
